package config

type Config struct {
	Log     Log     `mapstructure:"log" json:"log" yaml:"log"`
	Serve   Serve   `mapstructure:"serve" json:"serve" yaml:"serve"`
	Mysql   Mysql   `mapstructure:"mysql" json:"mysql" yaml:"mysql"`
	Redis   Redis   `mapstructure:"redis" json:"redis" yaml:"redis"`
	Smm     Smm     `mapstructure:"smm" json:"smm" yaml:"smm"`
	Xiangyu Xiangyu `mapstructure:"xiangyu" json:"xiangyu" yaml:"xiangyu"`
	Email   Email   `mapstructure:"email" json:"email" yaml:"email"`
	Oss     Oss     `mapstructure:"oss" json:"oss" yaml:"oss"`
}

// Serve gin服务配置
type Serve struct {
	Port      int    `mapstructure:"port" json:"port" yaml:"port" description:"gin开启监听http服务的端口"`
	RunMode   string `mapstructure:"run-mode" json:"run-mode" yaml:"run-mode" description:"gin运行模式的默认，枚举值：debug,release"`
	UseRedis  bool   `mapstructure:"use-redis" json:"use-redis" yaml:"use-redis" description:"是否使用redis"`
	AppName   string `mapstructure:"app-name" json:"app-name" yaml:"app-name" description:"项目名称"`
	StaticDir string `mapstructure:"static-dir" json:"static-dir" yaml:"static-dir" description:"上传的文件存储目录地址"`

	AppNameEn  string `mapstructure:"app-name-en" json:"app-name-en" yaml:"app-name-en" description:"项目名称英文"`
	Md5Key     string `mapstructure:"md5-key" json:"md5-key" yaml:"md5-key" description:"Md5密钥"`
	DesKey     string `mapstructure:"des-key" json:"des-key" yaml:"des-key" description:"Des密钥"`
	IsStopTask bool   `mapstructure:"is-stop-task" json:"is-stop-task" yaml:"is-stop-task" description:"是否停止任务，此功能用于多服务器部署时，定时任务只需一台服务器执行，其他服务器不执行的情况下设置为true"`
}

// Log 日志配置
type Log struct {
	Prefix          string `mapstructure:"prefix" json:"prefix" yaml:"prefix" description:"日志输出前缀"`
	LogFile         bool   `mapstructure:"log-file" json:"logFile" yaml:"log-file" description:""`
	Stdout          string `mapstructure:"stdout" json:"stdout" yaml:"stdout" description:""`
	FileStdout      string `mapstructure:"file-stdout" json:"file-stdout" yaml:"file-stdout" description:""`
	SaveMaxDay      int    `mapstructure:"save-max-day" json:"save-max-day" yaml:"save-max-day" description:"最多保留多少天的日志"`
	CuttingDay      int    `mapstructure:"cutting-day" json:"cutting-day" yaml:"cutting-day" description:"相隔几天切割文件"`
	LogDirPath      string `mapstructure:"log-dir-path" json:"log-dir-path" yaml:"log-dir-path" description:"日志目录"`
	LogSoftLink     string `mapstructure:"log-soft-link" json:"log-soft-link" yaml:"log-soft-link" description:"日志软链接"`
	BinlogDirPath   string `mapstructure:"binlog-dir-path" json:"binlog-dir-path" yaml:"binlog-dir-path" description:"binlog日志目录"`
	BinlogSoftLink  string `mapstructure:"binlog-soft-link" json:"binlog-soft-link" yaml:"binlog-soft-link" description:"binlog日志软链接"`
	FilelogDirPath  string `mapstructure:"filelog-dir-path" json:"filelog-dir-path" yaml:"filelog-dir-path" description:"用户自主记录的日志目录"`
	FilelogSoftLink string `mapstructure:"filelog-soft-link" json:"filelog-soft-link" yaml:"filelog-soft-link" description:"用户自主记录的日志软链接"`
}

// Mysql 数据库配置
type Mysql struct {
	//LogMode             bool        `mapstructure:"log-mode" json:"log-mode" yaml:"log-mode" description:"是否开启日志"`
	Stdout              bool        `mapstructure:"stdout" json:"stdout" yaml:"stdout" description:"日志是否输出在控制台"`
	DefaultDsnAliasName string      `mapstructure:"default-dsn-alias-name" json:"default-dsn-alias-name" yaml:"default-dsn-alias-name" description:"默认的数据库连接别名"`
	List                []MysqlConn `mapstructure:"list" json:"list" yaml:"list" description:"数据库链接配置列表"`
}

// MysqlConn mysql数据链接配置
type MysqlConn struct {
	Dsn          string `mapstructure:"dsn" json:"dsc" yaml:"dsn" description:"数据库连接配置"`
	AliasName    string `mapstructure:"alias-name" json:"alias-name" yaml:"alias-name" description:"数据库别名"`
	MaxIdleConns int    `mapstructure:"max-idle-conns" json:"max-idle-conns" yaml:"max-idle-conns" description:"最大空闲连接"`
	MaxOpenConns int    `mapstructure:"max-open-conns" json:"max-open-conns" yaml:"max-open-conns" description:"最大连接数"`
}

// Redis redis配置
type Redis struct {
	Address   string `mapstructure:"address" json:"address" yaml:"address" description:"redis服务链接地址"`
	Password  string `mapstructure:"password" json:"password" yaml:"password" description:"redis服务密码"`
	Db        int    `mapstructure:"db" json:"db" yaml:"db" description:"默认使用的redis库"`
	ServeType string `mapstructure:"serve-type" json:"serve-type" yaml:"serve-type" description:"redis服务类型，单机或者cluster；默认单机"`
}

// Smm smm配置
type Smm struct {
	Username string `mapstructure:"username" json:"username" yaml:"username" description:"smm账号"`
	Password string `mapstructure:"password" json:"password" yaml:"password" description:"smm密码"`
}

// Xiangyu 象屿的配置
type Xiangyu struct {
	SystemCode            string `mapstructure:"system-code" json:"system-code" yaml:"system-code" description:"系统编码"`
	UserSyncTarget        string `mapstructure:"user-sync-target" json:"user-sync-target" yaml:"user-sync-target" description:"用户同步平台编码"`
	UserSyncHost          string `mapstructure:"user-sync-host" json:"user-sync-host" yaml:"user-sync-host" description:"用户同步平台地址"`
	UserAuthHost          string `mapstructure:"user-auth-host" json:"user-auth-host" yaml:"user-auth-host" description:"用户认证平台地址"`
	UserSyncAuthUserName  string `mapstructure:"user-sync-auth-user-name" json:"user-sync-auth-user-name" yaml:"user-sync-auth-user-name" description:"用户统一身份的鉴权username"`
	UserSyncAuthPwd       string `mapstructure:"user-sync-auth-pwd" json:"user-sync-auth-pwd" yaml:"user-sync-auth-pwd" description:"用户统一身份的鉴权password"`
	UserKey               string `mapstructure:"user-key" json:"user-key" yaml:"user-key" description:"统一平台秘钥"`
	DefaultRoleId         int    `mapstructure:"default-role-id" json:"default-role-id" yaml:"default-role-id" description:"默认的角色id"`
	IndexSyncHost         string `mapstructure:"index-sync-host" json:"index-sync-host" yaml:"index-sync-host" description:"指标同步平台地址"`
	IndexSyncAuthUserName string `mapstructure:"index-sync-auth-user-name" json:"index-sync-auth-user-name" yaml:"index-sync-auth-user-name" description:"用户统一身份的鉴权username"`
	IndexSyncAuthPwd      string `mapstructure:"index-sync-auth-pwd" json:"index-sync-auth-pwd" yaml:"index-sync-auth-pwd" description:"用户统一身份的鉴权password"`
	IndexKey              string `mapstructure:"index-key" json:"index-key" yaml:"index-key" description:"统一平台秘钥"`
	IndexSyncTarget       string `mapstructure:"index-sync-target" json:"index-sync-target" yaml:"index-sync-target" description:"指标同步平台编码"`
	IndexCrmHost          string `mapstructure:"index-crm-host" json:"index-crm-host" yaml:"index-crm-host" description:"crm指标平台地址"`
	IndexCrmTarget        string `mapstructure:"index-crm-target" json:"index-crm-target" yaml:"index-crm-target" description:"crm指标平台编码"`
}

type Email struct {
	Host                            string   `mapstructure:"host" json:"host" yaml:"host" description:"邮件服务器"`
	Port                            int      `mapstructure:"port" json:"port" yaml:"port" description:"邮件服务器端口"`
	UserName                        string   `mapstructure:"username" json:"username" yaml:"username" description:"邮件服务器用户名"`
	Password                        string   `mapstructure:"password" json:"password" yaml:"password" description:"邮件服务器密码"`
	Folder                          string   `mapstructure:"folder" json:"folder" yaml:"folder" description:"邮件服务器文件夹"`
	ReadBatchSize                   int      `mapstructure:"read-batch-size" json:"read-batch-size" yaml:"read-batch-size" description:"邮件读取批次"`
	StartReadIndex                  int      `mapstructure:"start-read-index" json:"start-read-index" yaml:"start-read-index" description:"邮件开始读取的序号"`
	SyncEmailTime                   string   `mapstructure:"sync-email-time" json:"sync-email-time" yaml:"sync-email-time" description:"邮件同步时间"`
	IgnoreEmail                     []string `mapstructure:"ignore-email" json:"ignore-email" yaml:"ignore-email" description:"邮件过滤，不读取这些邮箱"`
	IgnoreEmailCaseSensitive        []string `mapstructure:"ignore-email-case-sensitive" json:"ignore-email-case-sensitive" yaml:"ignore-email-case-sensitive" description:"邮件过滤，不读取这些邮箱，大小写敏感"`
	IgnoreEmailAddress              []string `mapstructure:"ignore-email-address" json:"ignore-email-address" yaml:"ignore-email-address" description:"邮件过滤，不读取这些邮箱，大小写敏感"`
	IgnoreEmailAddressCaseSensitive []string `mapstructure:"ignore-email-address-case-sensitive" json:"ignore-email-address-case-sensitive" yaml:"ignore-email-address-case-sensitive" description:"邮件过滤，不读取这些邮箱，大小写敏感"`
	IgnoreEmailTitle                []string `mapstructure:"ignore-email-title" json:"ignore-email-title" yaml:"ignore-email-title" description:"邮件过滤，不读取这些标题"`
	IgnoreEmailTitleCaseSensitive   []string `mapstructure:"ignore-email-title-case-sensitive" json:"ignore-email-title-case-sensitive" yaml:"ignore-email-title-case-sensitive" description:"邮件过滤，不读取这些标题，大小写敏感"`
}

type Oss struct {
	ObjectStorageClient string `mapstructure:"object-storage-client" json:"object-storage-client" yaml:"object-storage-client" description:"oss类型，取值：oss minio,s3，默认oss"`
	EndPoint            string `mapstructure:"end-point" json:"end-point" yaml:"end-point" description:"oss服务地址"`
	BackEndPoint        string `mapstructure:"back-end-point" json:"back-end-point" yaml:"back-end-point" description:"oss服务地址（用于内网）"`
	AccessKeyId         string `mapstructure:"access-key-id" json:"access-key-id" yaml:"access-key-id" description:"oss服务access-key-id"`
	AccessKeySecret     string `mapstructure:"access-key-secret" json:"access-key-secret" yaml:"access-key-secret" description:"oss服务access-key-secret"`
	BucketName          string `mapstructure:"bucket-name" json:"bucket-name" yaml:"bucket-name" description:"oss服务bucketname"`
	RegionId            string `mapstructure:"region-id" json:"region-id" yaml:"region-id" description:"oss服务region-id"`
	ImgHost             string `mapstructure:"img-host" json:"img-host" yaml:"img-host" description:"oss服务imghost"`
	UploadDir           string `mapstructure:"upload-dir" json:"upload-dir" yaml:"upload-dir" description:"oss服务上传路径"`
	Port                string `mapstructure:"port" json:"port" yaml:"port" description:"oss服务端口"`
	ForceStyle          bool   `mapstructure:"force-style" json:"force-style" yaml:"force-style" description:"oss服务是否强制使用style,默认是True"`
	Protocol            string `mapstructure:"protocol" json:"protocol" yaml:"protocol" description:"oss服务协议，默认是http"`
	DisableSSL          bool   `mapstructure:"disable-ssl" json:"disable-ssl" yaml:"disable-ssl" description:"是否禁用ssl"`
	OpenAcl             bool   `mapstructure:"open-acl" json:"open-acl" yaml:"open-acl" description:"是否开启acl"`
	ResourceProxyUrl    string `mapstructure:"resource-proxy-url" json:"resource-proxy-url" yaml:"resource-proxy-url" description:"资源代理地址"`
	Ram                 OssRam `mapstructure:"ram" json:"ram" yaml:"ram"`
}

type OssRam struct {
	AccessKeyId      string `mapstructure:"access-key-id" json:"access-key-id" yaml:"access-key-id" description:"oss服务access-key-id"`
	AccessKeySecret  string `mapstructure:"access-key-secret" json:"access-key-secret" yaml:"access-key-secret" description:"oss服务access-key-secret"`
	StsScheme        string `mapstructure:"sts-scheme" json:"sts-scheme" yaml:"sts-scheme" description:"oss服务sts-scheme"`
	RoleArn          string `mapstructure:"role-arn" json:"role-arn" yaml:"role-arn" description:"oss服务role-arn"`
	RoleSessionName  string `mapstructure:"role-session-name" json:"role-session-name" yaml:"role-session-name" description:"oss服务role-session-name"`
	STSTokenCacheKey string `mapstructure:"sts-token-cache-key" json:"sts-token-cache-key" yaml:"sts-token-cache-key" description:"oss服务sts-token-cache-key（缓存key，用于获取后短期内不再重复获取）"`
}
