package report

import (
	"eta/eta_email_analysis/global"
	"time"
)

type Classify struct {
	Id                  int       `gorm:"column:id;primaryKey;autoIncrement"` // 注意：gorm 默认自增，所以 autoIncrement 可以省略
	ClassifyName        string    `gorm:"column:classify_name;size:125;default:'';comment:'分类名称'"`
	Sort                int       `gorm:"column:sort;type:tinyint;default:0;comment:'排序'"`
	ParentId            int       `gorm:"column:parent_id;default:0;comment:'父级分类id'"`
	CreateTime          time.Time `gorm:"column:create_time;comment:'创建时间'"`
	ModifyTime          time.Time `gorm:"column:modify_time;comment:'修改时间'"`
	Abstract            string    `gorm:"column:abstract;size:500;default:'';comment:'栏目简介'"`
	Descript            string    `gorm:"column:descript;size:500;default:'';comment:'分享描述'"`
	ReportAuthor        string    `gorm:"column:report_author;size:100;default:'';comment:'栏目作者'"`
	AuthorDescript       string    `gorm:"column:author_descript;size:500;default:'';comment:'作者简介'"`
	ReportImgUrl         string    `gorm:"column:report_img_url;size:255;default:'';comment:'报告配图'"`
	HeadImgUrl           string    `gorm:"column:head_img_url;size:255;default:'';comment:'头部banner'"`
	AvatarImgUrl         string    `gorm:"column:avatar_img_url;size:255;default:'';comment:'头像'"`
	ColumnImgUrl         string    `gorm:"column:column_img_url;size:255;default:'';comment:'栏目配图'"`
	IsHomeColumn         int       `gorm:"column:is_home_column;type:tinyint;default:0;comment:'1:首页专栏'"`
	HomeImgUrl           string    `gorm:"column:home_img_url;size:255;default:'';comment:'首页配图'"`
	ClassifyLabel        string    `gorm:"column:classify_label;size:500;default:''"`
	ShowType             int       `gorm:"column:show_type;type:tinyint unsigned;default:0;comment:'展示类型：1-列表 2-专栏 3-品种'"`
	HasTeleconference    int       `gorm:"column:has_teleconference;type:tinyint unsigned;default:0;comment:'是否有电话会 0-否 1-是'"`
	VipTitle             string    `gorm:"column:vip_title;size:200;comment:'研究员头衔'"`
	YbIconUrl            string    `gorm:"column:yb_icon_url;size:255;default:'';comment:'研报3.0已购页面icon图片地址'"`
	YbBgUrl              string    `gorm:"column:yb_bg_url;size:255;default:'';comment:'研报3.0已购详情背景图地址'"`
	IsShow               int       `gorm:"column:is_show;type:tinyint;default:1;comment:'是否展示报告：1,展示该分类下的报告，0隐藏分类下的报告'"`
	YbFiccSort           int       `gorm:"column:yb_ficc_sort;type:tinyint;default:0;comment:'研报小程序端ficc页面排序'"`
	YbFiccIcon           string    `gorm:"column:yb_ficc_icon;size:255;comment:'研报小程序端ficc页码图标'"`
	YbFiccPcIcon         string    `gorm:"column:yb_ficc_pc_icon;size:255;comment:'研报 pc端ficc页码图标'"`
	YbListImg            string    `gorm:"column:yb_list_img;size:255;default:'';comment:'研报小程序-列表封面图'"`
	YbShareBgImg         string    `gorm:"column:yb_share_bg_img;size:255;default:'';comment:'研报小程序-报告分享背景图'"`
	YbRightBanner        string    `gorm:"column:yb_right_banner;size:255;comment:'Pc端详情页，右侧，报告合集背景图'"`
	RelateTel            int       `gorm:"column:relate_tel;type:tinyint unsigned;default:0;comment:'是否在电话会中可选: 0-否; 1-是'"`
	RelateVideo          int       `gorm:"column:relate_video;type:tinyint unsigned;default:0;comment:'是否在路演视频中可选: 0-否; 1-是'"`
	IsMassSend           int       `gorm:"column:is_mass_send;type:tinyint;default:0;comment:'1:群发,0:非群发'"`
	Enabled              int       `gorm:"column:enabled;type:tinyint;default:1;comment:'是否可用'"`
	Level                int       `gorm:"column:level;type:int unsigned;default:0;comment:'层级'"`
	HasChild             int       `gorm:"column:has_child;type:tinyint unsigned;default:0;comment:'是否有子级别，0：下面没有子分类，1：下面有子分类；默认：0'"`
	ReportDetailShowType int       `gorm:"column:report_detail_show_type;type:tinyint unsigned;default:1;comment:'报告详情的展示类型：1-拼接；2:目录'"`
}

// tableName
func (m *Classify) TableName() string {
	return "classify"
}

func GetClassifyByClassifyId(classifyId int) (item *Classify, err error) {
	err = global.DEFAULT_MYSQL.Where("id = ?", classifyId).First(&item).Error
	return
}

func GetClassifyAll() (items []*Classify, err error) {
	err = global.DEFAULT_MYSQL.Model(&Classify{}).Scan(&items).Error
	return
}
